/**
 * This file is released under the GNU General Public License.
 * Refer to the COPYING file distributed with this package.
 *
 * Copyright (c) 2008-2009 WURFL-Pro srl
 */
package net.sourceforge.wurfl.core.handlers.matchers;

import java.util.SortedSet;

import net.sourceforge.wurfl.core.handlers.Handler;
import net.sourceforge.wurfl.core.handlers.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;
import net.sourceforge.wurfl.core.utils.StringUtils;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: KDDIMatcher.java 381 2009-11-17 14:29:45Z filippo.deluca $
 */
public class KDDIMatcher extends AbstractMatcher {

	public KDDIMatcher(Handler handler) {
		super(handler);
	}

	/**
	 * if UA starts with "KDDI/", apply RIS(SS) Otherwise apply RIS(FS)
	 */
	protected String lookForMatchingUserAgent(SortedSet userAgentsSet,
			String userAgent) {
		if (userAgent.startsWith("KDDI/")) {
			int tollerance = StringUtils.secondSlash(userAgent);

			if (logger.isDebugEnabled()) {
				logger.debug("Applying RIS(SS) UA: " + userAgent);
			}

			return StringUtils.risMatch(userAgentsSet, userAgent, tollerance);
		}

		return super.lookForMatchingUserAgent(userAgentsSet, userAgent);
	}

	protected String applyRecoveryMatch(WURFLRequest request,
			FilteredDevices filteredDevices) {
		return "opwv_v62_generic";
	}
}
