/**
 * This file is released under the GNU General Public License.
 * Refer to the COPYING file distributed with this package.
 *
 * Copyright (c) 2008-2009 WURFL-Pro srl
 */
package net.sourceforge.wurfl.core.request.normalizer.generic;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;

/**
 * YesWAP UserAgentNormalizer.
 * 
 * <p>
 * Remove the YesWAP from user-agent.
 * </p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: YesWAPNormalizer.java 381 2009-11-17 14:29:45Z filippo.deluca $
 */
public class YesWAPNormalizer implements UserAgentNormalizer {

	/** YesWAP regex pattern */
	private static final Pattern yesWapPattern = Pattern
			.compile("\\s*Mozilla/4\\.0 \\(YesWAP mobile phone proxy\\)");

	/**
	 * Replace the "YesWAP mobile phone proxy" with "".
	 */
	public String normalize(String userAgent) {

		String normalizedUserAgent = userAgent;

		Matcher matcher = yesWapPattern.matcher(userAgent);
		if (matcher.find()) {
			normalizedUserAgent = matcher.replaceAll("");
		}

		return normalizedUserAgent;
	}

}
